# Copyright (c) 2013 Cloudera, Inc. All rights reserved.

from pyinotify import ProcessEvent
import logging

LOG = logging.getLogger( __name__ )

class ImpaladINotifyEventProcessor(ProcessEvent):
  """
  This class extends pyinotify ProcessEvent class to receive filesystem events,
  allowing us to track rollover of impalad audit log file.  
  """
  
  def my_init(self, audit_logs):
    """
    ProcessEvent C'tor will call this method with optional parameter. Here is
    the doc verbatim:
    
    Note: you should not override __init__ in your subclass instead define 
    a my_init() method, this method will be called automatically from the 
    constructor of this class with its optional parameters.
    """
    self._audit_logs = audit_logs
    
  def process_IN_CREATE(self, event):
    """
    Called when a new file is created in the directory we are monitoring. We
    check that if this is because of log rotation and then start monitoring
    the new file. 
    """
    LOG.debug("Got a new file in directory: %s" % (event.name, ))
    self._audit_logs.append_new_log_to_list(event.name)

  def process_IN_DELETE(self, event):
    LOG.debug("%s file was deleted in audit directory." % (event.name, ))
    self._audit_logs.remove_log_from_list(event.name)

  def process_IN_MOVED_FROM(self, event):
    LOG.debug("%s was moved out of audit directory." % (event.name, ))
    self._audit_logs.remove_log_from_list(event.name)
